import { unstable_scheduleCallback as schedulePassiveEffects, unstable_cancelCallback as cancelPassiveEffects } from 'scheduler';
import warn from 'warning';
var NO_CONTEXT = true;

var NOOP = function NOOP() {};

export default {
  schedulePassiveEffects: schedulePassiveEffects,
  cancelPassiveEffects: cancelPassiveEffects,
  now: Date.now,
  prepareForCommit: NOOP,
  resetAfterCommit: NOOP,
  getRootHostContext: function getRootHostContext() {
    return NO_CONTEXT;
  },
  getChildHostContext: function getChildHostContext() {
    return NO_CONTEXT;
  },
  shouldSetTextContent: function shouldSetTextContent(type, props) {
    return typeof props.children === 'string' || typeof props.children === 'number';
  },
  createInstance: function createInstance() {
    var instance;
    return instance;
  },
  createTextInstance: function createTextInstance(text) {
    return text;
  },
  resetTextContent: NOOP,
  getPublicInstance: function getPublicInstance(instance) {
    return instance;
  },
  appendChildToContainer: function appendChildToContainer(parentInstance, child) {
    if (typeof child === 'string') {
      warn(false, 'React Vertex does not support text nodes.');
      return;
    }

    parentInstance.add(child);
  },
  removeChildFromContainer: function removeChildFromContainer(parentInstance, child) {
    parentInstance.remove(child);
  },
  appendInitialChild: function appendInitialChild(parentInstance, child) {
    if (typeof child === 'string') {
      warn(false, 'React Vertex does not support text nodes.');
      return;
    }

    parentInstance.add(child);
  },
  appendChild: function appendChild(parentInstance, child) {
    if (typeof child === 'string') {
      warn(false, 'React Vertex does not support text nodes.');
      return;
    }

    parentInstance.add(child);
  },
  removeChild: function removeChild(parentInstance, child) {
    parentInstance.remove(child);
  },
  insertBefore: NOOP,
  insertInContainerBefore: NOOP,
  finalizeInitialChildren: NOOP,
  supportsMutation: true,
  prepareUpdate: function prepareUpdate() {
    return true;
  },
  commitUpdate: function commitUpdate(instance, payload, type, oldProps, newProps) {
    instance.applyProps(newProps, oldProps);
  }
};