import {
  unstable_scheduleCallback as schedulePassiveEffects,
  unstable_cancelCallback as cancelPassiveEffects,
} from 'scheduler'
import warn from 'warning'

const NO_CONTEXT = true
const NOOP = () => {}

export default {
  schedulePassiveEffects,
  cancelPassiveEffects,
  now: Date.now,
  prepareForCommit: NOOP,
  resetAfterCommit: NOOP,
  getRootHostContext: () => NO_CONTEXT,
  getChildHostContext: () => NO_CONTEXT,
  shouldSetTextContent: (type, props) => {
    return (
      typeof props.children === 'string' || typeof props.children === 'number'
    )
  },
  createInstance: () => {
    let instance

    return instance
  },
  createTextInstance: text => text,
  resetTextContent: NOOP,
  getPublicInstance: instance => instance,
  appendChildToContainer: (parentInstance, child) => {
    if (typeof child === 'string') {
      warn(false, 'React Vertex does not support text nodes.')
      return
    }

    parentInstance.add(child)
  },
  removeChildFromContainer: (parentInstance, child) => {
    parentInstance.remove(child)
  },
  appendInitialChild: (parentInstance, child) => {
    if (typeof child === 'string') {
      warn(false, 'React Vertex does not support text nodes.')
      return
    }

    parentInstance.add(child)
  },
  appendChild: (parentInstance, child) => {
    if (typeof child === 'string') {
      warn(false, 'React Vertex does not support text nodes.')
      return
    }

    parentInstance.add(child)
  },
  removeChild: (parentInstance, child) => {
    parentInstance.remove(child)
  },
  insertBefore: NOOP,
  insertInContainerBefore: NOOP,
  finalizeInitialChildren: NOOP,
  supportsMutation: true,
  prepareUpdate: () => true,
  commitUpdate: (instance, payload, type, oldProps, newProps) => {
    instance.applyProps(newProps, oldProps)
  },
}
